/* MEDIA DATAMAKER	

This generates data for media_analysis.do. When run, it prepares the media files specifically
for regression with the Gallup & GSS data but it also establishes programs that can be called
afterward to load the presidential & placebo daily data onto memory without merging onto
Gallup & GSS data.. */

* Create temporary directory
shell mkdir tempdir

****************
** PARAMETERS **
****************

args prez keep smooth_option

if "`prez'"=="ike" {
	local full_name = "Eisenhower"
	global begin_office = "20jan1953"
	global end_office = "20jan1961"
	}
	
else if "`prez'"=="jfk" {
	local full_name = "Kennedy"
	global begin_office = "20jan1961"
	global end_office = "22nov1963"
	}

else if "`prez'"=="lbj" {
	local full_name = "Johnson"
	global begin_office = "22nov1963"
	global end_office = "20jan1969"
	}

* Default is to drop newspaper search data from dates outside of Gallup surveys
if "`keep'" == "" local keep = 3
else if "`keep'" == "keep" local keep = "2 3"

* Smooth option set is mandatory
disp "`smooth_option'"
if "`smooth_option'" == "" {
	display "Error. Please set smooth option."
	stop
	}

**************
** PROGRAMS **
**************
	
** BASIC PRESIDENTIAL DATA **
cap program drop PrepareBasic
program PrepareBasic
args prez full_name smooth_option staylong
use "$input/`prez'_14jan2015.dta", clear

	* Clean up dates
	decode date, gen(date_str)
	gen date_stata = date(date_str,"YMD")
	format date_stata %tdDD_Mon_YY

	* Reshape so that each search is a variable
	if "`staylong'"~="staylong" {
	reshape wide hits, j(search) i(date_stata)
		
	* Label hits variable (1-3) IKE (4-6) JFK LBJ (7-9)
	cap rename hits4 hits1
	cap rename hits5 hits2
	cap rename hits6 hits3
	cap rename hits7 hits1
	cap rename hits8 hits2
	cap rename hits9 hits3
	cap lab var hits1 "Civil Rights"
	cap lab var hits2 "Civil Rights Terms"
	cap lab var hits3 "Negro"

	* Set time series and smooth hits data
	tsset date_stata
	foreach var of varlist hits* {
		tssmooth ma smooth_`var'=`var', window(`smooth_option')
		local l_`var' : variable label `var'
		lab var smooth_`var' "`l_`var''"
		}
	sort date_stata
	}
end

** PLACEBO DATA **
cap program drop PreparePlacebo
program PreparePlacebo
args prez full_name smooth_option staylong
use "$input/`full_name'_placebo_1.26.2015.dta", clear

	* Clean up dates and other vars
	cap destring searchIndex, replace
	decode date, gen(date_str)
	gen date_stata = date(date_str,"YMD")
	format date_stata %tdDD_Mon_YY
	
	* Reshape so that each search is a variable
	if "`staylong'"~="staylong" {
	cap destring hits, replace
	drop search date date_str
	reshape wide hits, j(searchIndex) i(date_stata)
	
	* Rename and label placebo variables
	forval x = 1/13 {
		cap rename hits`x' placebo_`x'
		}
	
	label var placebo_1 "Placebo: President"
	label var placebo_2 "Placebo: Foreign Policy, War"
	label var placebo_3 "Placebo: Crime, Drugs"
	label var placebo_4 "Placebo: USSR"
	label var placebo_5 "Placebo: Cuba, Castro"
	label var placebo_6 "Placebo: Communism, Socialism"
	label var placebo_7 "Placebo: Taxes, Budget"
	label var placebo_8 "Placebo: Employment"
	label var placebo_9 "Placebo: Social Security"
	label var placebo_10 "Placebo: Agriculture"
	
	if "`prez'"=="ike" {
		local label_11 = "Placebo: Korea"
		local label_12 = "Placebo: Highways"
		}
	
	if "`prez'"=="lbj" {
		local label_11 = "Placebo: Riots"
		local label_12 = "Placebo: Vietnam"
		local label_13 = "Placebo: Poverty"
		}
		
	forval x=11/13 {
		cap label var placebo_`x' "`label_`x''"
		}	
		
	* Set time series and smooth hits data
	tsset date_stata
	foreach var of varlist placebo* {
		tssmooth ma smooth_`var'=`var', window(`smooth_option')
		local l_`var' : variable label `var'
		lab var smooth_`var' "`l_`var''"
		}
	sort date_stata
	}
end

*********************************
** PREPARE DATA FOR REGRESSION **
*********************************

disp "`prez'"
if "`prez'" ~= "get_programs_only" {

PrepareBasic `prez' `full_name' `smooth_option' gowide

	* Save to temporary file for later use
	label data "Basic daily data for `prez'"
	save tempdir/`prez'_media, replace
	
PreparePlacebo `prez' `full_name' `smooth_option' gowide

	* Save to temporary file for later use
	label data "Placebo daily data for `prez'"
	save tempdir/`prez'_placebo, replace
	
	
** GALLUP & GSS DATA **
use "$path/Input/gallup_and_GSS_extrayears.dta", clear

	* Drop dates outside the president's administration
	keep if svy_date>=date("$begin_office","DMY") & svy_date<=date("$end_office","DMY")

	* Drop non-whites to prepare for Census weighting 
	keep if race==1 
	
	* Census weighting 
	run "$do/make_gallup_cen_wgts.do" 
	
	* Merge in basic presidential data
	gen date_stata = svy_date
	sort date_stata
	merge m:1 date_stata using tempdir/`prez'_media, keep(`keep') nogenerate
	
	* Merge in placebo data
	merge m:1 date_stata using tempdir/`prez'_placebo, keep(`keep') nogenerate

	* Create variables for regression
	gen approve_01 = (presApprovala==1) if !missing(presApprovala)
	lab var approve_01 "(0/1)"

	gen approve_123=1 if approve_01==1 
	replace approve_123=.5 if presApprovala==3 
	replace approve_123=0 if approve_01==0 
	lab var approve_123 "(0/0.5/1)"
	
	* Create ln(articles) version of treatments
	foreach var of varlist smooth_hits* smooth_placebo* {
		gen ln_`var' = log(`var') if !missing(`var')
		local l_`var' : variable label `var'
		lab var ln_`var' "Log `l_`var''"
		}
	
	* Generate interactions with confed
	foreach var of varlist smooth_placebo* smooth_hits* ln_smooth_placebo* ln_smooth_hits* {
		gen conf_`var' = confed * `var'
		local l_`var' : variable label `var'
		lab var conf_`var' "South x `l_`var''"
		}
}
* Remove temporary directory created at start of do-file
!rm -r tempdir
capture !erase tempdir /q
*rmdir tempdir
